PCB Environment: Globals

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions, variables, defines, enums, and typedefs with links to the files they belong to:

### - _ -

- _PCB_GYM_LOG_IF : Log.hpp

### - a -

- adjustIndexForCutLayers() : Layer.hpp
- Aff_transformation_2 : Geometry.hpp
- ANY : Enums.hpp
- ASTAR_ALLOW_XOVER : AStar.hpp

### - b -

- Bbox_2 : Geometry.hpp

### - c -

- CanSafelyEraseOverlappingSegments : NavGrid.hpp
- CGAL_DISABLE_ROUNDING_MATH_CHECK : Geometry.hpp
- Circle_2 : Geometry.hpp
- ComSet : Actions.hpp
- ContactType : Track.hpp
- create_env() : Env.hpp
- cutLayersFromRange() : Layer.hpp

### - d -

- DEBUG : Log.hpp
- Direction_2 : Geometry.hpp

### - e -

- ERROR : Log.hpp

### - f -

- FloatNPArray : PyArray.hpp
- FMicrometers : Units.hpp

### - g -

- GROUND : Enums.hpp
- GYM_PCB_LOG_FORMAT_TIME : Log.hpp
- GYM_PCB_LOG_SHOW_THREAD : Log.hpp
- GYM_PCB_MAX_LOG_LEVEL : Log.hpp
- GYM_PCB_NAVPOINT_NUM_COST_TERMS : NavPoint.hpp

### - h -

- hugepage_size : HugePageAllocator.hpp

### - i -

- INFO : Log.hpp
- Iso_rectangle_2 : Geometry.hpp

### - k -

- Kernel : Geometry.hpp

### - l -

- Line_2 : Geometry.hpp
- LogLevel : Log.hpp

### - m -

- Meters : Units.hpp
- Micrometers : Units.hpp

### - n -

- Nanometers : Units.hpp
- NAV_IMAGE_CHAN_PIN_B : NavImage.hpp
- NAV_IMAGE_CHAN_PIN_T : NavImage.hpp
- NAV_IMAGE_CHAN_RATSNEST_B : NavImage.hpp
- NAV_IMAGE_CHAN_RATSNEST_T : NavImage.hpp
- NAV_IMAGE_CHAN_TRACK_B : NavImage.hpp
- NAV_IMAGE_CHAN_TRACK_M : NavImage.hpp
- NAV_IMAGE_CHAN_TRACK_T : NavImage.hpp
- NAV_IMAGE_CHAN_VIA : NavImage.hpp
- NAV_IMAGE_NUM_CHANS : NavImage.hpp
- NAV_POINT_FLAG_BLOCKED_PERMANENT : NavPoint.hpp
- NAV_POINT_FLAG_BLOCKED_TEMPORARY : NavPoint.hpp
- NAV_POINT_FLAG_INSIDE_COMPONENT : NavPoint.hpp
- NAV_POINT_FLAG_INSIDE_PIN : NavPoint.hpp
- NAV_POINT_FLAG_NO_VIAS : NavPoint.hpp
- NAV_POINT_FLAG_PIN_TRACK_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_PIN_VIA_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_ROUTE_GUARD : NavPoint.hpp
- NAV_POINT_FLAG_ROUTE_TRACK_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_ROUTE_VIA_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_SOURCE : NavPoint.hpp
- NAV_POINT_FLAG_TARGET : NavPoint.hpp
- NAV_POINT_FLAGS_ALL : NavPoint.hpp
- NAV_POINT_FLAGS_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_ENDPOINT : NavPoint.hpp
- NAV_POINT_FLAGS_PIN_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_ROUTE_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_TRACK_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_TRACKS_BLOCKED : NavPoint.hpp
- NAV_POINT_FLAGS_VIA_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_VIAS_BLOCKED : NavPoint.hpp
- NAV_POINT_FLAGS_VIAS_BLOCKED_P : NavPoint.hpp
- NO_IMPORT_ARRAY : Py.hpp
- NOTICE : Log.hpp
- NPY_NO_DEPRECATED_API : Py.hpp

### - o -

- operator!=() : HugePageAllocator.hpp
- operator<<() : AShape.hpp, Geometry.hpp, Units.hpp, IPoint2.hpp, IPoint3.hpp
- operator==() : HugePageAllocator.hpp

### - p -

- PCB_CHANGED_COMPONENTS : PCBoard.hpp
- PCB_CHANGED_NAV_GRID : PCBoard.hpp
- PCB_CHANGED_NAV_TRIS : PCBoard.hpp
- PCB_CHANGED_NET_COLORS : PCBoard.hpp
- PCB_CHANGED_NEW_BOARD : PCBoard.hpp
- PCB_CHANGED_OBJECTS : PCBoard.hpp
- PCB_CHANGED_OBJECTS_SET : PCBoard.hpp
- PCB_CHANGED_PINS : PCBoard.hpp
- PCB_CHANGED_ROUTES : PCBoard.hpp
- PCB_PY_I_METHOD_EVENT : Agent.hpp
- PCB_PY_I_METHOD_P : Agent.hpp
- PCB_PY_I_METHOD_P_V : Agent.hpp
- PCB_PY_I_METHOD_Q : Agent.hpp
- PCB_PY_I_METHOD_V : Agent.hpp
- PEDANTIC : Defs.hpp
- PERF_COUNTER_D : AStar.hpp
- PERF_COUNTER_T : AStar.hpp
- PinCompound : Pin.hpp
- PinSet : Actions.hpp
- Point_2 : Geometry.hpp
- Point_3 : Geometry.hpp
- Polygon_2 : Geometry.hpp
- POWER : Enums.hpp
- POWER_GROUND : Enums.hpp
- PY_ARRAY_UNIQUE_SYMBOL : Py.hpp
- PY_ONLY : Py.hpp

### - r -

- RASTERIZE_CAPS_MASK_BOTH : Rasterizer.hpp
- RASTERIZE_CAPS_MASK_SOURCE : Rasterizer.hpp
- RASTERIZE_CAPS_MASK_TARGET : Rasterizer.hpp
- RASTERIZE_MASK_ALL : Rasterizer.hpp
- RASTERIZE_MASK_CAPS : Rasterizer.hpp
- RASTERIZE_MASK_CAPS_AND_JUNCTIONS : Rasterizer.hpp
- RASTERIZE_MASK_JUNCTIONS : Rasterizer.hpp
- RASTERIZE_MASK_SEGMENTS : Rasterizer.hpp
- RASTERIZE_MASK_VIAS : Rasterizer.hpp
- Ray_2 : Geometry.hpp
- Ray_3 : Geometry.hpp
- Real : Defs.hpp
- RETURN_ERROR : Log.hpp
- Reward : Reward.hpp

### - s -

- Segment_2 : Geometry.hpp
- Segment_3 : Geometry.hpp
- SIGNAL : Enums.hpp
- SIGNAL_GROUND : Enums.hpp
- SIGNAL_POWER : Enums.hpp
- SignalType : Enums.hpp
- signalType() : Enums.hpp
- std_08x : Defs.hpp
- std_get_for_cgal : Geometry.hpp

### - t -

- to_string() : Enums.hpp
- TRACE : Log.hpp
- Triangle_2 : Geometry.hpp
- Triangle_3 : Geometry.hpp

### - u -

- uint : Defs.hpp
- USER : Enums.hpp

### - v -

- Vector_2 : Geometry.hpp
- Vector_3 : Geometry.hpp

### - w -

- WARN : Log.hpp
- WITH_LOCK : Defs.hpp
- WITH_LOCKGUARD : FancyLock.hpp
- WITH_RLOCK : Defs.hpp
- WITH_WLOCK : Defs.hpp